@@ -1,10 +1,10 @@
 # © Copyright Databand.ai, an IBM Company 2022
 
 # we should run bootstrap first! before we import any other pyspark object
-from dbnd_spark.spark_bootstrap import dbnd_spark_bootstrap
+from dbnd_spark.spark_bootstrap import workaround_spark_namedtuple_serialization
 
 
-dbnd_spark_bootstrap()
+workaround_spark_namedtuple_serialization()
 
 __all__ = []
 
