@@ -8,25 +8,21 @@ from typing import Union
 
 import more_itertools
 
-from dbnd._core.cli.cmd_execute import get_dbnd_version, get_python_version
 from dbnd._core.constants import TaskType
 from dbnd._core.errors import DatabandBuildError, DatabandConfigError
 from dbnd._core.errors.friendly_error.task_build import incomplete_output_found_for_task
 from dbnd._core.parameter.parameter_builder import output, parameter
-from dbnd._core.task.decorated_callable_task import _DecoratedCallableTask
-from dbnd._core.task.task import Task
 from dbnd._core.task_build.dbnd_decorator import build_task_decorator
 from dbnd._core.utils.project.project_fs import databand_lib_path
 from dbnd._core.utils.structures import list_of_strings
 from dbnd._core.utils.traversing import flatten
-from dbnd.tasks.py_distribution.fat_wheel_tasks import ProjectWheelFile
+from dbnd_run.cli.cmd_execute import get_dbnd_version, get_python_version
+from dbnd_run.task.decorated_callable_task import _DecoratedCallableTask
+from dbnd_run.task.task import Task
+from dbnd_run.tasks.py_distribution.fat_wheel_tasks import ProjectWheelFile
 from dbnd_spark.local.local_spark_config import SparkLocalEngineConfig
 from dbnd_spark.spark_config import SparkConfig, SparkEngineConfig
-from dbnd_spark.spark_session import (
-    get_spark_session,
-    inject_spark_listener,
-    shutdown_callback_server,
-)
+from dbnd_spark.spark_session import get_spark_session
 from targets import DirTarget
 from targets.types import PathStr
 
@@ -166,13 +162,16 @@ class PySparkInlineTask(_BaseSparkTask):
         return self._application_args
 
     def _use_spark_context_inplace(self):
-        from dbnd_spark.spark_session import has_spark_session
+        from dbnd.providers.spark.dbnd_spark_init import has_active_spark_session
 
         if isinstance(self.spark_engine, SparkLocalEngineConfig):
-            if self.spark_engine.enable_spark_context_inplace and has_spark_session():
+            if (
+                self.spark_engine.enable_spark_context_inplace
+                and has_active_spark_session()
+            ):
                 return True
 
-        if self.spark_config.use_current_spark_session and has_spark_session():
+        if self.spark_config.use_current_spark_session and has_active_spark_session():
             return True
 
         return False
@@ -216,24 +215,8 @@ class PySparkInlineTask(_BaseSparkTask):
         )
 
     def _task_run(self):
-        if self.spark_config.listener_inject_enabled:
-            try:
-                inject_spark_listener(get_spark_session())
-            except Exception as e:
-                logger.error(
-                    "Unable to inject Databand Spark Listener. Error: %s" % (e,)
-                )
-
         super(PySparkInlineTask, self)._task_run()
 
-        if self.spark_config.listener_inject_enabled:
-            try:
-                shutdown_callback_server()
-            except Exception as e:
-                logger.error(
-                    "Unable to shutdown Py4J callback server. Error: %s" % (e,)
-                )
-
         if self._get_spark_ctrl().stop_spark_session_on_finish:
             session = get_spark_session()
             logger.info("Stopping spark session: %s")
