@@ -129,12 +129,6 @@ class SparkConfig(Config):
         description="If Spark Session exists, do not send to remote cluster/spark-submit, but use existing.",
     )
 
-    listener_inject_enabled = parameter.value(
-        False,
-        description="Enable Auto-injecting Databand Spark Listener. "
-        "This listener will record and report spark metrics to the databand server.",
-    )
-
     include_user_project = parameter.c(
         default=False,
         description="Enable building fat_wheel from configured package and third-party requirements"
@@ -163,19 +157,3 @@ class SparkEngineConfig(Config):
     disable_task_band = parameter(
         default=False, description="Disable task_band file creation"
     )[bool]
-
-
-class SparkMarshallingConfig(Config):
-    _conf__task_family = "spark_marshalling"
-    default_infer_schema_value = parameter(
-        default=False,
-        description="Should the DataFrame to CSV "
-        "marshaller infer schema by default. Can be overridden via `parameter.save_options` or "
-        "`parameter.load_options` on the relevant parameter",
-    )[bool]
-    default_header_value = parameter(
-        default=False,
-        description="Should the DataFrame to CSV "
-        "marshaller set header by default. Can be overridden via `parameter.save_options` or "
-        "`parameter.load_options` on the relevant parameter",
-    )[bool]
